git.lucas.co / cce-compositor
Wayland compositor (wlroots)
git clone https://git.lucas.co/cce-compositor.git

commitb2ca7fe5ec6185455cb37df9eb96474ee7384095
parent0eaddab0b3
authorLucas Galante <[email protected]>
date2026-06-19 14:54
Rename clearctl to cce-ctl

 src/bin/cce.rs                  | 4 ++--
 src/{clearctl.rs => cce_ctl.rs} | 4 ++--
 src/lib.rs                      | 6 +++---
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/src/bin/cce.rs b/src/bin/cce.rs
index f49f0e3..e3b5997 100644
--- a/src/bin/cce.rs
+++ b/src/bin/cce.rs
@@ -9,9 +9,9 @@ fn main() {
                 std::process::exit(0);
             }
             "control" => {
-                let mut control_args = vec!["clearctl".to_string()];
+                let mut control_args = vec!["cce-ctl".to_string()];
                 control_args.extend(args.iter().skip(2).cloned());
-                cce::run_clearctl(control_args);
+                cce::run_cce_ctl(control_args);
             }
             "--help" | "-h" | "help" => {
                 print_help();
diff --git a/src/lib.rs b/src/lib.rs
index 1cf30a3..1a98484 100644
--- a/src/lib.rs
+++ b/src/lib.rs
@@ -104,6 +104,6 @@ pub use run_server::run_server;
 // ==========================================
 // IPC Client Modules
 // ==========================================
-#[path = "clearctl.rs"]
-pub mod clearctl;
-pub use clearctl::run_clearctl;
+#[path = "cce_ctl.rs"]
+pub mod cce_ctl;
+pub use cce_ctl::run_cce_ctl;
diff --git a/src/clearctl.rs b/src/cce_ctl.rs
similarity index 97%
rename from src/clearctl.rs
rename to src/cce_ctl.rs
index d72cea6..e4dea4c 100644
--- a/src/clearctl.rs
+++ b/src/cce_ctl.rs
@@ -1,4 +1,4 @@
 // clearctl — IPC client for cce
  
 use std::env;
 use std::fs;
@@ -66,7 +66,7 @@ fn usage(name: &str, to_stderr: bool) {
     print("  key-release <key>");
 }
  
-pub fn run_clearctl(args: Vec<String>) {
+pub fn run_cce_ctl(args: Vec<String>) {
     if args.len() < 2 {
         usage(&args[0], true);
         process::exit(1);
@@ -1,4 +1,4 @@
-// clearctl — IPC client for cce
+// cce-ctl — IPC client for cce
  
 use std::env;